==> nextcloud-25.0.5.tgz: nextcloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "See %s" : "Vaata %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Authentication" : "Autentimine",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Files" : "Failid",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "_%n hour ago_::_%n hours ago_" : ["%n tund tagasi","%n tundi tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "Empty file" : "Tühi fail",
    "File already exists" : "Fail on juba olemas",
    "Invalid path" : "Vigane kataloogirada",
    "Failed to create file from template" : "Ei saa luua mallist faili",
    "Templates" : "Mallid",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Help" : "Abi",
    "Apps" : "Rakendused",
    "Personal settings" : "Isiklikud seaded",
    "Administration settings" : "Administreerimise seaded",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Users" : "Kasutajad",
    "Email" : "Epost",
    "Phone" : "Telefon",
    "Twitter" : "Twitter",
    "Website" : "Veebileht",
    "Address" : "Aadress",
    "Profile picture" : "Profiili pilt",
    "About" : "Info",
    "Full name" : "Täisnimi",
    "Organisation" : "Organisatsioon",
    "Role" : "Roll",
    "Unknown user" : "Tundmatu kasutaja",
    "Additional settings" : "Lisaseaded",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin username." : "Määra admin kasutajanimi.",
    "Set an admin password." : "Määra admini parool.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "Open »%s«" : "Ava »%s«",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Cannot increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Sharing %s failed, because this item is already shared with user %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud kasutajaga %s",
    "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "The username is already being used" : "Kasutajanimi on juba kasutuses",
    "Could not create user" : "Ei saanud kasutajat luua",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "Username contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
    "Username must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
    "User disabled" : "Kasutaja deaktiveeritud",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "Please upgrade your database version." : "Palun uuenda oma andmebaasi versioon",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
    "Your data directory is invalid." : "Sinu andmekataloog on vigane",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "%s enter the database username and name." : "%s sisesta andmebaasi kasutajatunnus ja nimi.",
    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kasutajanimes on lubatud ainult järgmised sümbolid: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\""
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.7.tgz: nextcloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "See %s" : "Vaata %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Authentication" : "Autentimine",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Files" : "Failid",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "_%n hour ago_::_%n hours ago_" : ["%n tund tagasi","%n tundi tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "Empty file" : "Tühi fail",
    "File already exists" : "Fail on juba olemas",
    "Invalid path" : "Vigane kataloogirada",
    "Failed to create file from template" : "Ei saa luua mallist faili",
    "Templates" : "Mallid",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Help" : "Abi",
    "Apps" : "Rakendused",
    "Personal settings" : "Isiklikud seaded",
    "Administration settings" : "Administreerimise seaded",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Users" : "Kasutajad",
    "Email" : "Epost",
    "Phone" : "Telefon",
    "Twitter" : "Twitter",
    "Website" : "Veebileht",
    "Address" : "Aadress",
    "Profile picture" : "Profiili pilt",
    "About" : "Info",
    "Display name" : "Kuvatav nimi",
    "Organisation" : "Organisatsioon",
    "Role" : "Roll",
    "Unknown user" : "Tundmatu kasutaja",
    "Additional settings" : "Lisaseaded",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin username." : "Määra admin kasutajanimi.",
    "Set an admin password." : "Määra admini parool.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "Open »%s«" : "Ava »%s«",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Cannot increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Sharing %s failed, because this item is already shared with user %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud kasutajaga %s",
    "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "The username is already being used" : "Kasutajanimi on juba kasutuses",
    "Could not create user" : "Ei saanud kasutajat luua",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "Username contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
    "Username must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
    "User disabled" : "Kasutaja deaktiveeritud",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP seade \"%s\" ei ole \"%s\".",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "Please upgrade your database version." : "Palun uuenda oma andmebaasi versioon",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
    "Your data directory is invalid." : "Sinu andmekataloog on vigane",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Full name" : "Täisnimi",
    "%s enter the database username and name." : "%s sisesta andmebaasi kasutajatunnus ja nimi.",
    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kasutajanimes on lubatud ainult järgmised sümbolid: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vaja on vähemalt libxml2 2.7.0. Hetkel on installitud %s."
},
"nplurals=2; plural=(n != 1);");
